@@ -23,37 +23,27 @@ from ..serializer.pkl_gzip import serialize, deserialize
 from ..utils.async_ import to_sync
 from ..utils.check_ import check_methods
 
+# 二进制拆包
+BYTES_PER_SEND = 1024 * 32
 
-def process_response(r):
-    """处理响应。根据不同的响应分别处理
 
-    Parameters
-    ----------
-    r: Response
+def process_response_dict(data):
+    # data = deserialize(r)
+    if data['status'] == 200:
+        return data['data']
+    return data
 
-    Returns
-    -------
-    object
-    json
-    csv
 
-    """
-    if isinstance(r, bytes):
-        # 二进制，反序列化后是字典
-        data = deserialize(r)
-        if data['status'] == 200:
-            return data['data']
-        return data
-    else:
-        # json字符串转成字字典
-        data = json_to_dict(r)
-        # 特殊类型先还原
-        if data.get('type', None) in ('DataFrame', 'Series', 'ndarray'):
-            data['data'] = dict_to_obj(data['data'])
-        # 成功响应直接返回数据区
-        if data['status'] == 200:
-            return data['data']
-        return data
+def process_response_json(r):
+    # json字符串转成字字典
+    data = json_to_dict(r)
+    # 特殊类型先还原
+    if data.get('type', None) in ('DataFrame', 'Series', 'ndarray'):
+        data['data'] = dict_to_obj(data['data'])
+    # 成功响应直接返回数据区
+    if data['status'] == 200:
+        return data['data']
+    return data
 
 
 class WebSocketConnection:
@@ -76,7 +66,7 @@ class WebSocketConnection:
 
         headers = None if self._token is None else {"Authorization": f"Bearer {self._token}"}
         # 默认是2**20，只有1MB，扩充一下成8MB
-        self._client = connect(self._url, extra_headers=headers, max_size=2**23)
+        self._client = connect(self._url, extra_headers=headers, max_size=2 ** 23)
 
         self._ws = await self._client.__aenter__()
         self._with = True
@@ -112,20 +102,38 @@ class WebSocketConnection:
 
         if self._fmt == Format.PKL_GZIP:
             # 二进制格式
-            await self._ws.send(serialize(d).read())
+            b = serialize(d).read()
+            bl = len(b)
+            await self._ws.send(serialize(bl).read())
+            for i in range(0, len(b), BYTES_PER_SEND):
+                await self._ws.send(b[i:i + BYTES_PER_SEND])
         else:
             # json格式
             await self._ws.send(dict_to_json(d))
 
+        # 这里收到的数据是否需要解析一下，如果是二进制的，需要特别处理
         rsp = await self._ws.recv()
-        return process_response(rsp)
+        if isinstance(rsp, bytes):
+            # 二进制，反序列化后是字典
+            bl = deserialize(rsp)
+            rsp = b''
+            while len(rsp) < bl:
+                rsp += await self._ws.recv()
+            return process_response_dict(deserialize(rsp))
+        else:
+            return process_response_json(rsp)
 
     async def reverse(self):
         """反弹RPC的被控端"""
         while True:
             req = await self._ws.recv()
+            bl = deserialize(req)
+            req = b''
+            while len(req) < bl:
+                req += await self._ws.recv()
             req = deserialize(req)
-            logger.info(req)
+            # 可能显示太多，需要裁剪一些
+            logger.info(repr(req)[:200])
             # 不需要缓存
             req['cache_get'] = False
             req['cache_expire'] = 0
@@ -140,18 +148,27 @@ class WebSocketConnection:
                         raise Exception(f'Method Not Allowed, {func} not in allowlist')
                     if not check_methods(METHODS_BLOCK, methods, True):
                         raise Exception(f'Method Not Allowed, {func} in blocklist')
-
-                key, buf, data = await call(**req)
+                # 每个连上去的都分别使用了自己的用户名，这里不需要用户名即可操作
+                user = 'reverse'
+                key, buf, data = await call(user, **req)
             except Exception as e:
                 # 主要是处理
                 key = type(e).__name__
                 # 这里没有缓存，因为这个错误是服务器内部检查
                 data = RspModel(status=401,  # status.HTTP_401_UNAUTHORIZED,
                                 datetime=datetime.now().isoformat(),
-                                func=func, args=req['args'], kwargs=req['args'])
+                                func=func, args=req['args'], kwargs=req['kwargs'])
                 data.type = type(e).__name__
                 data.data = repr(e)
                 data = data.dict()
                 buf = serialize(data).read()
 
-            await self._ws.send(buf)
+            # 将这里分成两种处理方法
+            bl = len(buf)
+            print('需要发送字节数', bl, end='')
+            await self._ws.send(serialize(bl).read())
+            for i in range(0, len(buf), BYTES_PER_SEND):
+                print('-', end='')
+                await self._ws.send(buf[i:i + BYTES_PER_SEND])
+                print('+', end='')
+            print('发送完成')
